scopus.ScopusAffiliation
========================

.. currentmodule:: scopus

.. autoclass:: ScopusAffiliation
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ScopusAffiliation.address
      ~ScopusAffiliation.affiliation_id
      ~ScopusAffiliation.city
      ~ScopusAffiliation.country
      ~ScopusAffiliation.name
      ~ScopusAffiliation.nauthors
      ~ScopusAffiliation.ndocuments
      ~ScopusAffiliation.url
